<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moblyze\Logbook\Http\Requests\EmergencyDrillRequest;
use Moblyze\Logbook\Interfaces\EmergencyDrillRepositoryInterface;
use Moblyze\Logbook\Models\EmergencyDrill;
use Moblyze\Logbook\Forms\EmergencyDrill as Form;

/**
 * APIController  class for emergency_drill.
 */
class EmergencyDrillAPIController extends BaseController
{

    /**
     * Initialize emergency_drill resource controller.
     *
     * @param type EmergencyDrillRepositoryInterface $emergency_drill
     *
     * @return null
     */
    public function __construct(EmergencyDrillRepositoryInterface $emergency_drill)
    {
        parent::__construct();
        $this->repository = $emergency_drill;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\EmergencyDrillResourceCriteria::class);
    }

    /**
     * Display a list of emergency_drill.
     *
     * @return Response
     */
    public function index(EmergencyDrillRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\EmergencyDrillPresenter::class)
            ->paginate();
    }

    /**
     * Display emergency_drill.
     *
     * @param Request $request
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function show(EmergencyDrillRequest $request, EmergencyDrill $emergency_drill)
    {
        return $emergency_drill->setPresenter(\Moblyze\Logbook\Repositories\Presenter\EmergencyDrillListPresenter::class);
        ;
    }

    /**
     * Create new emergency_drill.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EmergencyDrillRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('logbook::emergency_drill.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/emergency_drill');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the emergency_drill.
     *
     * @param Request $request
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function update(EmergencyDrillRequest $request, EmergencyDrill $emergency_drill)
    {
        try {
            $data = $request->all();

            $emergency_drill->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('logbook::emergency_drill.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the emergency_drill.
     *
     * @param Model   $emergency_drill
     *
     * @return Response
     */
    public function destroy(EmergencyDrillRequest $request, EmergencyDrill $emergency_drill)
    {
        try {
            $emergency_drill->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('logbook::emergency_drill.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('logbook/emergency_drill/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/emergency_drill/' . $emergency_drill->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
