<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moblyze\Logbook\Http\Requests\IameDetailRequest;
use Moblyze\Logbook\Interfaces\IameDetailRepositoryInterface;
use Moblyze\Logbook\Models\IameDetail;
use Moblyze\Logbook\Forms\IameDetail as Form;

/**
 * APIController  class for iame_detail.
 */
class IameDetailAPIController extends BaseController
{

    /**
     * Initialize iame_detail resource controller.
     *
     * @param type IameDetailRepositoryInterface $iame_detail
     *
     * @return null
     */
    public function __construct(IameDetailRepositoryInterface $iame_detail)
    {
        parent::__construct();
        $this->repository = $iame_detail;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\IameDetailResourceCriteria::class);
    }

    /**
     * Display a list of iame_detail.
     *
     * @return Response
     */
    public function index(IameDetailRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\IameDetailPresenter::class)
            ->paginate();
    }

    /**
     * Display iame_detail.
     *
     * @param Request $request
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function show(IameDetailRequest $request, IameDetail $iame_detail)
    {
        return $iame_detail->setPresenter(\Moblyze\Logbook\Repositories\Presenter\IameDetailListPresenter::class);
        ;
    }

    /**
     * Create new iame_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IameDetailRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('logbook::iame_detail.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/iame_detail');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the iame_detail.
     *
     * @param Request $request
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function update(IameDetailRequest $request, IameDetail $iame_detail)
    {
        try {
            $data = $request->all();

            $iame_detail->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('logbook::iame_detail.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the iame_detail.
     *
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function destroy(IameDetailRequest $request, IameDetail $iame_detail)
    {
        try {
            $iame_detail->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('logbook::iame_detail.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('logbook/iame_detail/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
