<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Moblyze\Logbook\Http\Requests\IameDetailRequest;
use Moblyze\Logbook\Interfaces\IameDetailRepositoryInterface;
use Moblyze\Logbook\Models\IameDetail;

/**
 * Resource controller class for iame_detail.
 */
class IameDetailResourceController extends BaseController
{

    /**
     * Initialize iame_detail resource controller.
     *
     * @param type IameDetailRepositoryInterface $iame_detail
     *
     * @return null
     */
    public function __construct(IameDetailRepositoryInterface $iame_detail)
    {
        parent::__construct();
        $this->repository = $iame_detail;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\IameDetailResourceCriteria::class);
    }

    /**
     * Display a list of iame_detail.
     *
     * @return Response
     */
    public function index(IameDetailRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\IameDetailPresenter::class)
                ->$function();
        }

        $iame_details = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('logbook::iame_detail.names'))
            ->view('logbook::iame_detail.index', true)
            ->data(compact('iame_details', 'view'))
            ->output();
    }

    /**
     * Display iame_detail.
     *
     * @param Request $request
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function show(IameDetailRequest $request, IameDetail $iame_detail)
    {

        if ($iame_detail->exists) {
            $view = 'logbook::iame_detail.show';
        } else {
            $view = 'logbook::iame_detail.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('logbook::iame_detail.name'))
            ->data(compact('iame_detail'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new iame_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(IameDetailRequest $request)
    {

        $iame_detail = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('logbook::iame_detail.name')) 
            ->view('logbook::iame_detail.create', true) 
            ->data(compact('iame_detail'))
            ->output();
    }

    /**
     * Create new iame_detail.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IameDetailRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $iame_detail                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('logbook::iame_detail.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/logbook/iame_detail'))
                ->redirect();
        }

    }

    /**
     * Show iame_detail for editing.
     *
     * @param Request $request
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function edit(IameDetailRequest $request, IameDetail $iame_detail)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('logbook::iame_detail.name'))
            ->view('logbook::iame_detail.edit', true)
            ->data(compact('iame_detail'))
            ->output();
    }

    /**
     * Update the iame_detail.
     *
     * @param Request $request
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function update(IameDetailRequest $request, IameDetail $iame_detail)
    {
        try {
            $attributes = $request->all();

            $iame_detail->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('logbook::iame_detail.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the iame_detail.
     *
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function destroy(IameDetailRequest $request, IameDetail $iame_detail)
    {
        try {

            $iame_detail->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::iame_detail.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('logbook/iame_detail/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/iame_detail/' . $iame_detail->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple iame_detail.
     *
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function delete(IameDetailRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::iame_detail.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('logbook/iame_detail'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/iame_detail'))
                ->redirect();
        }

    }

    /**
     * Restore deleted iame_details.
     *
     * @param Model   $iame_detail
     *
     * @return Response
     */
    public function restore(IameDetailRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('logbook::iame_detail.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/logbook/iame_detail'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/iame_detail/'))
                ->redirect();
        }

    }

}
