<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moblyze\Logbook\Http\Requests\LogbookMasterRequest;
use Moblyze\Logbook\Interfaces\LogbookMasterRepositoryInterface;
use Moblyze\Logbook\Models\LogbookMaster;
use Moblyze\Logbook\Forms\LogbookMaster as Form;

/**
 * APIController  class for logbook_master.
 */
class LogbookMasterAPIController extends BaseController
{

    /**
     * Initialize logbook_master resource controller.
     *
     * @param type LogbookMasterRepositoryInterface $logbook_master
     *
     * @return null
     */
    public function __construct(LogbookMasterRepositoryInterface $logbook_master)
    {
        parent::__construct();
        $this->repository = $logbook_master;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\LogbookMasterResourceCriteria::class);
    }

    /**
     * Display a list of logbook_master.
     *
     * @return Response
     */
    public function index(LogbookMasterRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\LogbookMasterPresenter::class)
            ->paginate();
    }

    /**
     * Display logbook_master.
     *
     * @param Request $request
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function show(LogbookMasterRequest $request, LogbookMaster $logbook_master)
    {
        return $logbook_master->setPresenter(\Moblyze\Logbook\Repositories\Presenter\LogbookMasterListPresenter::class);
        ;
    }

    /**
     * Create new logbook_master.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LogbookMasterRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('logbook::logbook_master.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/logbook_master');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the logbook_master.
     *
     * @param Request $request
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function update(LogbookMasterRequest $request, LogbookMaster $logbook_master)
    {
        try {
            $data = $request->all();

            $logbook_master->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('logbook::logbook_master.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the logbook_master.
     *
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function destroy(LogbookMasterRequest $request, LogbookMaster $logbook_master)
    {
        try {
            $logbook_master->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('logbook::logbook_master.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('logbook/logbook_master/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
