<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Moblyze\Logbook\Http\Requests\LogbookMasterRequest;
use Moblyze\Logbook\Interfaces\LogbookMasterRepositoryInterface;
use Moblyze\Logbook\Models\LogbookMaster;

/**
 * Resource controller class for logbook_master.
 */
class LogbookMasterResourceController extends BaseController
{

    /**
     * Initialize logbook_master resource controller.
     *
     * @param type LogbookMasterRepositoryInterface $logbook_master
     *
     * @return null
     */
    public function __construct(LogbookMasterRepositoryInterface $logbook_master)
    {
        parent::__construct();
        $this->repository = $logbook_master;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\LogbookMasterResourceCriteria::class);
    }

    /**
     * Display a list of logbook_master.
     *
     * @return Response
     */
    public function index(LogbookMasterRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\LogbookMasterPresenter::class)
                ->$function();
        }

        $logbook_masters = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('logbook::logbook_master.names'))
            ->view('logbook::logbook_master.index', true)
            ->data(compact('logbook_masters', 'view'))
            ->output();
    }

    /**
     * Display logbook_master.
     *
     * @param Request $request
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function show(LogbookMasterRequest $request, LogbookMaster $logbook_master)
    {

        if ($logbook_master->exists) {
            $view = 'logbook::logbook_master.show';
        } else {
            $view = 'logbook::logbook_master.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('logbook::logbook_master.name'))
            ->data(compact('logbook_master'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new logbook_master.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LogbookMasterRequest $request)
    {

        $logbook_master = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('logbook::logbook_master.name')) 
            ->view('logbook::logbook_master.create', true) 
            ->data(compact('logbook_master'))
            ->output();
    }

    /**
     * Create new logbook_master.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LogbookMasterRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $logbook_master                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('logbook::logbook_master.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/logbook/logbook_master'))
                ->redirect();
        }

    }

    /**
     * Show logbook_master for editing.
     *
     * @param Request $request
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function edit(LogbookMasterRequest $request, LogbookMaster $logbook_master)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('logbook::logbook_master.name'))
            ->view('logbook::logbook_master.edit', true)
            ->data(compact('logbook_master'))
            ->output();
    }

    /**
     * Update the logbook_master.
     *
     * @param Request $request
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function update(LogbookMasterRequest $request, LogbookMaster $logbook_master)
    {
        try {
            $attributes = $request->all();

            $logbook_master->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('logbook::logbook_master.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the logbook_master.
     *
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function destroy(LogbookMasterRequest $request, LogbookMaster $logbook_master)
    {
        try {

            $logbook_master->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::logbook_master.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('logbook/logbook_master/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/logbook_master/' . $logbook_master->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple logbook_master.
     *
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function delete(LogbookMasterRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::logbook_master.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('logbook/logbook_master'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/logbook_master'))
                ->redirect();
        }

    }

    /**
     * Restore deleted logbook_masters.
     *
     * @param Model   $logbook_master
     *
     * @return Response
     */
    public function restore(LogbookMasterRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('logbook::logbook_master.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/logbook/logbook_master'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/logbook_master/'))
                ->redirect();
        }

    }

}
