<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Moblyze\Logbook\Http\Requests\SafetyBriefingRequest;
use Moblyze\Logbook\Interfaces\SafetyBriefingRepositoryInterface;
use Moblyze\Logbook\Models\SafetyBriefing;

/**
 * Resource controller class for safety_briefing.
 */
class SafetyBriefingResourceController extends BaseController
{

    /**
     * Initialize safety_briefing resource controller.
     *
     * @param type SafetyBriefingRepositoryInterface $safety_briefing
     *
     * @return null
     */
    public function __construct(SafetyBriefingRepositoryInterface $safety_briefing)
    {
        parent::__construct();
        $this->repository = $safety_briefing;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\SafetyBriefingResourceCriteria::class);
    }

    /**
     * Display a list of safety_briefing.
     *
     * @return Response
     */
    public function index(SafetyBriefingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\SafetyBriefingPresenter::class)
                ->$function();
        }

        $safety_briefings = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('logbook::safety_briefing.names'))
            ->view('logbook::safety_briefing.index', true)
            ->data(compact('safety_briefings', 'view'))
            ->output();
    }

    /**
     * Display safety_briefing.
     *
     * @param Request $request
     * @param Model   $safety_briefing
     *
     * @return Response
     */
    public function show(SafetyBriefingRequest $request, SafetyBriefing $safety_briefing)
    {

        if ($safety_briefing->exists) {
            $view = 'logbook::safety_briefing.show';
        } else {
            $view = 'logbook::safety_briefing.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('logbook::safety_briefing.name'))
            ->data(compact('safety_briefing'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new safety_briefing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SafetyBriefingRequest $request)
    {

        $safety_briefing = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('logbook::safety_briefing.name')) 
            ->view('logbook::safety_briefing.create', true) 
            ->data(compact('safety_briefing'))
            ->output();
    }

    /**
     * Create new safety_briefing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SafetyBriefingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $safety_briefing                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('logbook::safety_briefing.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/safety_briefing/' . $safety_briefing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/logbook/safety_briefing'))
                ->redirect();
        }

    }

    /**
     * Show safety_briefing for editing.
     *
     * @param Request $request
     * @param Model   $safety_briefing
     *
     * @return Response
     */
    public function edit(SafetyBriefingRequest $request, SafetyBriefing $safety_briefing)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('logbook::safety_briefing.name'))
            ->view('logbook::safety_briefing.edit', true)
            ->data(compact('safety_briefing'))
            ->output();
    }

    /**
     * Update the safety_briefing.
     *
     * @param Request $request
     * @param Model   $safety_briefing
     *
     * @return Response
     */
    public function update(SafetyBriefingRequest $request, SafetyBriefing $safety_briefing)
    {
        try {
            $attributes = $request->all();

            $safety_briefing->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('logbook::safety_briefing.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/safety_briefing/' . $safety_briefing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/safety_briefing/' . $safety_briefing->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the safety_briefing.
     *
     * @param Model   $safety_briefing
     *
     * @return Response
     */
    public function destroy(SafetyBriefingRequest $request, SafetyBriefing $safety_briefing)
    {
        try {

            $safety_briefing->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::safety_briefing.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('logbook/safety_briefing/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/safety_briefing/' . $safety_briefing->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple safety_briefing.
     *
     * @param Model   $safety_briefing
     *
     * @return Response
     */
    public function delete(SafetyBriefingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::safety_briefing.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('logbook/safety_briefing'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/safety_briefing'))
                ->redirect();
        }

    }

    /**
     * Restore deleted safety_briefings.
     *
     * @param Model   $safety_briefing
     *
     * @return Response
     */
    public function restore(SafetyBriefingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('logbook::safety_briefing.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/logbook/safety_briefing'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/safety_briefing/'))
                ->redirect();
        }

    }

}
