<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Moblyze\Logbook\Http\Requests\VesselLogbookRequest;
use Moblyze\Logbook\Interfaces\VesselLogbookRepositoryInterface;
use Moblyze\Logbook\Models\VesselLogbook;
use Moblyze\Logbook\Forms\VesselLogbook as Form;

/**
 * APIController  class for vessel_logbook.
 */
class VesselLogbookAPIController extends BaseController
{

    /**
     * Initialize vessel_logbook resource controller.
     *
     * @param type VesselLogbookRepositoryInterface $vessel_logbook
     *
     * @return null
     */
    public function __construct(VesselLogbookRepositoryInterface $vessel_logbook)
    {
        parent::__construct();
        $this->repository = $vessel_logbook;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\VesselLogbookResourceCriteria::class);
    }

    /**
     * Display a list of vessel_logbook.
     *
     * @return Response
     */
    public function index(VesselLogbookRequest $request)
    {
        return $this->repository
            ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\VesselLogbookPresenter::class)
            ->paginate();
    }

    /**
     * Display vessel_logbook.
     *
     * @param Request $request
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function show(VesselLogbookRequest $request, VesselLogbook $vessel_logbook)
    {
        return $vessel_logbook->setPresenter(\Moblyze\Logbook\Repositories\Presenter\VesselLogbookListPresenter::class);
        ;
    }

    /**
     * Create new vessel_logbook.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VesselLogbookRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('logbook::vessel_logbook.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/vessel_logbook');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the vessel_logbook.
     *
     * @param Request $request
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function update(VesselLogbookRequest $request, VesselLogbook $vessel_logbook)
    {
        try {
            $data = $request->all();

            $vessel_logbook->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('logbook::vessel_logbook.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the vessel_logbook.
     *
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function destroy(VesselLogbookRequest $request, VesselLogbook $vessel_logbook)
    {
        try {
            $vessel_logbook->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('logbook::vessel_logbook.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('logbook/vessel_logbook/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
