<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Moblyze\Logbook\Http\Requests\VesselLogbookRequest;
use Moblyze\Logbook\Interfaces\VesselLogbookRepositoryInterface;
use Moblyze\Logbook\Models\VesselLogbook;

/**
 * Resource controller class for vessel_logbook.
 */
class VesselLogbookResourceController extends BaseController
{

    /**
     * Initialize vessel_logbook resource controller.
     *
     * @param type VesselLogbookRepositoryInterface $vessel_logbook
     *
     * @return null
     */
    public function __construct(VesselLogbookRepositoryInterface $vessel_logbook)
    {
        parent::__construct();
        $this->repository = $vessel_logbook;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\VesselLogbookResourceCriteria::class);
    }

    /**
     * Display a list of vessel_logbook.
     *
     * @return Response
     */
    public function index(VesselLogbookRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\VesselLogbookPresenter::class)
                ->$function();
        }

        $vessel_logbooks = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('logbook::vessel_logbook.names'))
            ->view('logbook::vessel_logbook.index', true)
            ->data(compact('vessel_logbooks', 'view'))
            ->output();
    }

    /**
     * Display vessel_logbook.
     *
     * @param Request $request
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function show(VesselLogbookRequest $request, VesselLogbook $vessel_logbook)
    {

        if ($vessel_logbook->exists) {
            $view = 'logbook::vessel_logbook.show';
        } else {
            $view = 'logbook::vessel_logbook.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('logbook::vessel_logbook.name'))
            ->data(compact('vessel_logbook'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new vessel_logbook.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(VesselLogbookRequest $request)
    {

        $vessel_logbook = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('logbook::vessel_logbook.name')) 
            ->view('logbook::vessel_logbook.create', true) 
            ->data(compact('vessel_logbook'))
            ->output();
    }

    /**
     * Create new vessel_logbook.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VesselLogbookRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $vessel_logbook                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('logbook::vessel_logbook.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/logbook/vessel_logbook'))
                ->redirect();
        }

    }

    /**
     * Show vessel_logbook for editing.
     *
     * @param Request $request
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function edit(VesselLogbookRequest $request, VesselLogbook $vessel_logbook)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('logbook::vessel_logbook.name'))
            ->view('logbook::vessel_logbook.edit', true)
            ->data(compact('vessel_logbook'))
            ->output();
    }

    /**
     * Update the vessel_logbook.
     *
     * @param Request $request
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function update(VesselLogbookRequest $request, VesselLogbook $vessel_logbook)
    {
        try {
            $attributes = $request->all();

            $vessel_logbook->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('logbook::vessel_logbook.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the vessel_logbook.
     *
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function destroy(VesselLogbookRequest $request, VesselLogbook $vessel_logbook)
    {
        try {

            $vessel_logbook->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::vessel_logbook.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('logbook/vessel_logbook/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/vessel_logbook/' . $vessel_logbook->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple vessel_logbook.
     *
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function delete(VesselLogbookRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::vessel_logbook.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('logbook/vessel_logbook'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/vessel_logbook'))
                ->redirect();
        }

    }

    /**
     * Restore deleted vessel_logbooks.
     *
     * @param Model   $vessel_logbook
     *
     * @return Response
     */
    public function restore(VesselLogbookRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('logbook::vessel_logbook.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/logbook/vessel_logbook'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/vessel_logbook/'))
                ->redirect();
        }

    }

}
