<?php

namespace Moblyze\Logbook\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Moblyze\Logbook\Http\Requests\VesselRunningSheetRequest;
use Moblyze\Logbook\Interfaces\VesselRunningSheetRepositoryInterface;
use Moblyze\Logbook\Models\VesselRunningSheet;

/**
 * Resource controller class for vessel_running_sheet.
 */
class VesselRunningSheetResourceController extends BaseController
{

    /**
     * Initialize vessel_running_sheet resource controller.
     *
     * @param type VesselRunningSheetRepositoryInterface $vessel_running_sheet
     *
     * @return null
     */
    public function __construct(VesselRunningSheetRepositoryInterface $vessel_running_sheet)
    {
        parent::__construct();
        $this->repository = $vessel_running_sheet;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Moblyze\Logbook\Repositories\Criteria\VesselRunningSheetResourceCriteria::class);
    }

    /**
     * Display a list of vessel_running_sheet.
     *
     * @return Response
     */
    public function index(VesselRunningSheetRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Moblyze\Logbook\Repositories\Presenter\VesselRunningSheetPresenter::class)
                ->$function();
        }

        $vessel_running_sheets = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('logbook::vessel_running_sheet.names'))
            ->view('logbook::vessel_running_sheet.index', true)
            ->data(compact('vessel_running_sheets', 'view'))
            ->output();
    }

    /**
     * Display vessel_running_sheet.
     *
     * @param Request $request
     * @param Model   $vessel_running_sheet
     *
     * @return Response
     */
    public function show(VesselRunningSheetRequest $request, VesselRunningSheet $vessel_running_sheet)
    {

        if ($vessel_running_sheet->exists) {
            $view = 'logbook::vessel_running_sheet.show';
        } else {
            $view = 'logbook::vessel_running_sheet.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('logbook::vessel_running_sheet.name'))
            ->data(compact('vessel_running_sheet'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new vessel_running_sheet.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(VesselRunningSheetRequest $request)
    {

        $vessel_running_sheet = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('logbook::vessel_running_sheet.name')) 
            ->view('logbook::vessel_running_sheet.create', true) 
            ->data(compact('vessel_running_sheet'))
            ->output();
    }

    /**
     * Create new vessel_running_sheet.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VesselRunningSheetRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $vessel_running_sheet                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('logbook::vessel_running_sheet.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/vessel_running_sheet/' . $vessel_running_sheet->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/logbook/vessel_running_sheet'))
                ->redirect();
        }

    }

    /**
     * Show vessel_running_sheet for editing.
     *
     * @param Request $request
     * @param Model   $vessel_running_sheet
     *
     * @return Response
     */
    public function edit(VesselRunningSheetRequest $request, VesselRunningSheet $vessel_running_sheet)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('logbook::vessel_running_sheet.name'))
            ->view('logbook::vessel_running_sheet.edit', true)
            ->data(compact('vessel_running_sheet'))
            ->output();
    }

    /**
     * Update the vessel_running_sheet.
     *
     * @param Request $request
     * @param Model   $vessel_running_sheet
     *
     * @return Response
     */
    public function update(VesselRunningSheetRequest $request, VesselRunningSheet $vessel_running_sheet)
    {
        try {
            $attributes = $request->all();

            $vessel_running_sheet->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('logbook::vessel_running_sheet.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('logbook/vessel_running_sheet/' . $vessel_running_sheet->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/vessel_running_sheet/' . $vessel_running_sheet->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the vessel_running_sheet.
     *
     * @param Model   $vessel_running_sheet
     *
     * @return Response
     */
    public function destroy(VesselRunningSheetRequest $request, VesselRunningSheet $vessel_running_sheet)
    {
        try {

            $vessel_running_sheet->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::vessel_running_sheet.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('logbook/vessel_running_sheet/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('logbook/vessel_running_sheet/' . $vessel_running_sheet->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple vessel_running_sheet.
     *
     * @param Model   $vessel_running_sheet
     *
     * @return Response
     */
    public function delete(VesselRunningSheetRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('logbook::vessel_running_sheet.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('logbook/vessel_running_sheet'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/vessel_running_sheet'))
                ->redirect();
        }

    }

    /**
     * Restore deleted vessel_running_sheets.
     *
     * @param Model   $vessel_running_sheet
     *
     * @return Response
     */
    public function restore(VesselRunningSheetRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('logbook::vessel_running_sheet.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/logbook/vessel_running_sheet'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/logbook/vessel_running_sheet/'))
                ->redirect();
        }

    }

}
