<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\AssetLogbook;

class AssetLogbookPolicy
{

    /**
     * Determine if the given user can view the asset_logbook.
     *
     * @param UserPolicy $user
     * @param AssetLogbook $asset_logbook
     *
     * @return bool
     */
    public function view(UserPolicy $user, AssetLogbook $asset_logbook)
    {
        if ($user->canDo('logbook.asset_logbook.view') && $user->isAdmin()) {
            return true;
        }

        return $asset_logbook->user_id == user_id() && $asset_logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can create a asset_logbook.
     *
     * @param UserPolicy $user
     * @param AssetLogbook $asset_logbook
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.asset_logbook.create');
    }

    /**
     * Determine if the given user can update the given asset_logbook.
     *
     * @param UserPolicy $user
     * @param AssetLogbook $asset_logbook
     *
     * @return bool
     */
    public function update(UserPolicy $user, AssetLogbook $asset_logbook)
    {
        if ($user->canDo('logbook.asset_logbook.edit') && $user->isAdmin()) {
            return true;
        }

        return $asset_logbook->user_id == user_id() && $asset_logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given asset_logbook.
     *
     * @param UserPolicy $user
     * @param AssetLogbook $asset_logbook
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, AssetLogbook $asset_logbook)
    {
        return $asset_logbook->user_id == user_id() && $asset_logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given asset_logbook.
     *
     * @param UserPolicy $user
     * @param AssetLogbook $asset_logbook
     *
     * @return bool
     */
    public function verify(UserPolicy $user, AssetLogbook $asset_logbook)
    {
        if ($user->canDo('logbook.asset_logbook.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given asset_logbook.
     *
     * @param UserPolicy $user
     * @param AssetLogbook $asset_logbook
     *
     * @return bool
     */
    public function approve(UserPolicy $user, AssetLogbook $asset_logbook)
    {
        if ($user->canDo('logbook.asset_logbook.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
