<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\EmergencyDrill;

class EmergencyDrillPolicy
{

    /**
     * Determine if the given user can view the emergency_drill.
     *
     * @param UserPolicy $user
     * @param EmergencyDrill $emergency_drill
     *
     * @return bool
     */
    public function view(UserPolicy $user, EmergencyDrill $emergency_drill)
    {
        if ($user->canDo('logbook.emergency_drill.view') && $user->isAdmin()) {
            return true;
        }

        return $emergency_drill->user_id == user_id() && $emergency_drill->user_type == user_type();
    }

    /**
     * Determine if the given user can create a emergency_drill.
     *
     * @param UserPolicy $user
     * @param EmergencyDrill $emergency_drill
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.emergency_drill.create');
    }

    /**
     * Determine if the given user can update the given emergency_drill.
     *
     * @param UserPolicy $user
     * @param EmergencyDrill $emergency_drill
     *
     * @return bool
     */
    public function update(UserPolicy $user, EmergencyDrill $emergency_drill)
    {
        if ($user->canDo('logbook.emergency_drill.edit') && $user->isAdmin()) {
            return true;
        }

        return $emergency_drill->user_id == user_id() && $emergency_drill->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given emergency_drill.
     *
     * @param UserPolicy $user
     * @param EmergencyDrill $emergency_drill
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EmergencyDrill $emergency_drill)
    {
        return $emergency_drill->user_id == user_id() && $emergency_drill->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given emergency_drill.
     *
     * @param UserPolicy $user
     * @param EmergencyDrill $emergency_drill
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EmergencyDrill $emergency_drill)
    {
        if ($user->canDo('logbook.emergency_drill.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given emergency_drill.
     *
     * @param UserPolicy $user
     * @param EmergencyDrill $emergency_drill
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EmergencyDrill $emergency_drill)
    {
        if ($user->canDo('logbook.emergency_drill.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
