<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\IameDetail;

class IameDetailPolicy
{

    /**
     * Determine if the given user can view the iame_detail.
     *
     * @param UserPolicy $user
     * @param IameDetail $iame_detail
     *
     * @return bool
     */
    public function view(UserPolicy $user, IameDetail $iame_detail)
    {
        if ($user->canDo('logbook.iame_detail.view') && $user->isAdmin()) {
            return true;
        }

        return $iame_detail->user_id == user_id() && $iame_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can create a iame_detail.
     *
     * @param UserPolicy $user
     * @param IameDetail $iame_detail
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.iame_detail.create');
    }

    /**
     * Determine if the given user can update the given iame_detail.
     *
     * @param UserPolicy $user
     * @param IameDetail $iame_detail
     *
     * @return bool
     */
    public function update(UserPolicy $user, IameDetail $iame_detail)
    {
        if ($user->canDo('logbook.iame_detail.edit') && $user->isAdmin()) {
            return true;
        }

        return $iame_detail->user_id == user_id() && $iame_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given iame_detail.
     *
     * @param UserPolicy $user
     * @param IameDetail $iame_detail
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, IameDetail $iame_detail)
    {
        return $iame_detail->user_id == user_id() && $iame_detail->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given iame_detail.
     *
     * @param UserPolicy $user
     * @param IameDetail $iame_detail
     *
     * @return bool
     */
    public function verify(UserPolicy $user, IameDetail $iame_detail)
    {
        if ($user->canDo('logbook.iame_detail.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given iame_detail.
     *
     * @param UserPolicy $user
     * @param IameDetail $iame_detail
     *
     * @return bool
     */
    public function approve(UserPolicy $user, IameDetail $iame_detail)
    {
        if ($user->canDo('logbook.iame_detail.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
