<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\LogbookMaster;

class LogbookMasterPolicy
{

    /**
     * Determine if the given user can view the logbook_master.
     *
     * @param UserPolicy $user
     * @param LogbookMaster $logbook_master
     *
     * @return bool
     */
    public function view(UserPolicy $user, LogbookMaster $logbook_master)
    {
        if ($user->canDo('logbook.logbook_master.view') && $user->isAdmin()) {
            return true;
        }

        return $logbook_master->user_id == user_id() && $logbook_master->user_type == user_type();
    }

    /**
     * Determine if the given user can create a logbook_master.
     *
     * @param UserPolicy $user
     * @param LogbookMaster $logbook_master
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.logbook_master.create');
    }

    /**
     * Determine if the given user can update the given logbook_master.
     *
     * @param UserPolicy $user
     * @param LogbookMaster $logbook_master
     *
     * @return bool
     */
    public function update(UserPolicy $user, LogbookMaster $logbook_master)
    {
        if ($user->canDo('logbook.logbook_master.edit') && $user->isAdmin()) {
            return true;
        }

        return $logbook_master->user_id == user_id() && $logbook_master->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given logbook_master.
     *
     * @param UserPolicy $user
     * @param LogbookMaster $logbook_master
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LogbookMaster $logbook_master)
    {
        return $logbook_master->user_id == user_id() && $logbook_master->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given logbook_master.
     *
     * @param UserPolicy $user
     * @param LogbookMaster $logbook_master
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LogbookMaster $logbook_master)
    {
        if ($user->canDo('logbook.logbook_master.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given logbook_master.
     *
     * @param UserPolicy $user
     * @param LogbookMaster $logbook_master
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LogbookMaster $logbook_master)
    {
        if ($user->canDo('logbook.logbook_master.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
