<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\PassengerManifest;

class PassengerManifestPolicy
{

    /**
     * Determine if the given user can view the passenger_manifest.
     *
     * @param UserPolicy $user
     * @param PassengerManifest $passenger_manifest
     *
     * @return bool
     */
    public function view(UserPolicy $user, PassengerManifest $passenger_manifest)
    {
        if ($user->canDo('logbook.passenger_manifest.view') && $user->isAdmin()) {
            return true;
        }

        return $passenger_manifest->user_id == user_id() && $passenger_manifest->user_type == user_type();
    }

    /**
     * Determine if the given user can create a passenger_manifest.
     *
     * @param UserPolicy $user
     * @param PassengerManifest $passenger_manifest
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.passenger_manifest.create');
    }

    /**
     * Determine if the given user can update the given passenger_manifest.
     *
     * @param UserPolicy $user
     * @param PassengerManifest $passenger_manifest
     *
     * @return bool
     */
    public function update(UserPolicy $user, PassengerManifest $passenger_manifest)
    {
        if ($user->canDo('logbook.passenger_manifest.edit') && $user->isAdmin()) {
            return true;
        }

        return $passenger_manifest->user_id == user_id() && $passenger_manifest->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given passenger_manifest.
     *
     * @param UserPolicy $user
     * @param PassengerManifest $passenger_manifest
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PassengerManifest $passenger_manifest)
    {
        return $passenger_manifest->user_id == user_id() && $passenger_manifest->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given passenger_manifest.
     *
     * @param UserPolicy $user
     * @param PassengerManifest $passenger_manifest
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PassengerManifest $passenger_manifest)
    {
        if ($user->canDo('logbook.passenger_manifest.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given passenger_manifest.
     *
     * @param UserPolicy $user
     * @param PassengerManifest $passenger_manifest
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PassengerManifest $passenger_manifest)
    {
        if ($user->canDo('logbook.passenger_manifest.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
