<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\SafetyBriefing;

class SafetyBriefingPolicy
{

    /**
     * Determine if the given user can view the safety_briefing.
     *
     * @param UserPolicy $user
     * @param SafetyBriefing $safety_briefing
     *
     * @return bool
     */
    public function view(UserPolicy $user, SafetyBriefing $safety_briefing)
    {
        if ($user->canDo('logbook.safety_briefing.view') && $user->isAdmin()) {
            return true;
        }

        return $safety_briefing->user_id == user_id() && $safety_briefing->user_type == user_type();
    }

    /**
     * Determine if the given user can create a safety_briefing.
     *
     * @param UserPolicy $user
     * @param SafetyBriefing $safety_briefing
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.safety_briefing.create');
    }

    /**
     * Determine if the given user can update the given safety_briefing.
     *
     * @param UserPolicy $user
     * @param SafetyBriefing $safety_briefing
     *
     * @return bool
     */
    public function update(UserPolicy $user, SafetyBriefing $safety_briefing)
    {
        if ($user->canDo('logbook.safety_briefing.edit') && $user->isAdmin()) {
            return true;
        }

        return $safety_briefing->user_id == user_id() && $safety_briefing->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given safety_briefing.
     *
     * @param UserPolicy $user
     * @param SafetyBriefing $safety_briefing
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SafetyBriefing $safety_briefing)
    {
        return $safety_briefing->user_id == user_id() && $safety_briefing->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given safety_briefing.
     *
     * @param UserPolicy $user
     * @param SafetyBriefing $safety_briefing
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SafetyBriefing $safety_briefing)
    {
        if ($user->canDo('logbook.safety_briefing.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given safety_briefing.
     *
     * @param UserPolicy $user
     * @param SafetyBriefing $safety_briefing
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SafetyBriefing $safety_briefing)
    {
        if ($user->canDo('logbook.safety_briefing.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
