<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\VesselLogbook;

class VesselLogbookPolicy
{

    /**
     * Determine if the given user can view the vessel_logbook.
     *
     * @param UserPolicy $user
     * @param VesselLogbook $vessel_logbook
     *
     * @return bool
     */
    public function view(UserPolicy $user, VesselLogbook $vessel_logbook)
    {
        if ($user->canDo('logbook.vessel_logbook.view') && $user->isAdmin()) {
            return true;
        }

        return $vessel_logbook->user_id == user_id() && $vessel_logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vessel_logbook.
     *
     * @param UserPolicy $user
     * @param VesselLogbook $vessel_logbook
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.vessel_logbook.create');
    }

    /**
     * Determine if the given user can update the given vessel_logbook.
     *
     * @param UserPolicy $user
     * @param VesselLogbook $vessel_logbook
     *
     * @return bool
     */
    public function update(UserPolicy $user, VesselLogbook $vessel_logbook)
    {
        if ($user->canDo('logbook.vessel_logbook.edit') && $user->isAdmin()) {
            return true;
        }

        return $vessel_logbook->user_id == user_id() && $vessel_logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vessel_logbook.
     *
     * @param UserPolicy $user
     * @param VesselLogbook $vessel_logbook
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, VesselLogbook $vessel_logbook)
    {
        return $vessel_logbook->user_id == user_id() && $vessel_logbook->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vessel_logbook.
     *
     * @param UserPolicy $user
     * @param VesselLogbook $vessel_logbook
     *
     * @return bool
     */
    public function verify(UserPolicy $user, VesselLogbook $vessel_logbook)
    {
        if ($user->canDo('logbook.vessel_logbook.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vessel_logbook.
     *
     * @param UserPolicy $user
     * @param VesselLogbook $vessel_logbook
     *
     * @return bool
     */
    public function approve(UserPolicy $user, VesselLogbook $vessel_logbook)
    {
        if ($user->canDo('logbook.vessel_logbook.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
