<?php

namespace Moblyze\Logbook\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Logbook\Models\VesselRunningSheet;

class VesselRunningSheetPolicy
{

    /**
     * Determine if the given user can view the vessel_running_sheet.
     *
     * @param UserPolicy $user
     * @param VesselRunningSheet $vessel_running_sheet
     *
     * @return bool
     */
    public function view(UserPolicy $user, VesselRunningSheet $vessel_running_sheet)
    {
        if ($user->canDo('logbook.vessel_running_sheet.view') && $user->isAdmin()) {
            return true;
        }

        return $vessel_running_sheet->user_id == user_id() && $vessel_running_sheet->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vessel_running_sheet.
     *
     * @param UserPolicy $user
     * @param VesselRunningSheet $vessel_running_sheet
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('logbook.vessel_running_sheet.create');
    }

    /**
     * Determine if the given user can update the given vessel_running_sheet.
     *
     * @param UserPolicy $user
     * @param VesselRunningSheet $vessel_running_sheet
     *
     * @return bool
     */
    public function update(UserPolicy $user, VesselRunningSheet $vessel_running_sheet)
    {
        if ($user->canDo('logbook.vessel_running_sheet.edit') && $user->isAdmin()) {
            return true;
        }

        return $vessel_running_sheet->user_id == user_id() && $vessel_running_sheet->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vessel_running_sheet.
     *
     * @param UserPolicy $user
     * @param VesselRunningSheet $vessel_running_sheet
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, VesselRunningSheet $vessel_running_sheet)
    {
        return $vessel_running_sheet->user_id == user_id() && $vessel_running_sheet->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vessel_running_sheet.
     *
     * @param UserPolicy $user
     * @param VesselRunningSheet $vessel_running_sheet
     *
     * @return bool
     */
    public function verify(UserPolicy $user, VesselRunningSheet $vessel_running_sheet)
    {
        if ($user->canDo('logbook.vessel_running_sheet.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vessel_running_sheet.
     *
     * @param UserPolicy $user
     * @param VesselRunningSheet $vessel_running_sheet
     *
     * @return bool
     */
    public function approve(UserPolicy $user, VesselRunningSheet $vessel_running_sheet)
    {
        if ($user->canDo('logbook.vessel_running_sheet.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
