<?php

namespace Moblyze\Logbook\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Moblyze\Logbook\Models\Logbook;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Moblyze\Logbook\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/logbook/passenger_manifest/*')) {
            Route::bind('passenger_manifest', function ($passenger_manifest) {
                $passenger_manifestrepo = $this->app->make('Moblyze\Logbook\Interfaces\PassengerManifestRepositoryInterface');
                return $passenger_manifestrepo->findorNew($passenger_manifest);
            });
        }

        if (Request::is('*/logbook/logbook_master/*')) {
            Route::bind('logbook_master', function ($logbook_master) {
                $logbook_masterrepo = $this->app->make('Moblyze\Logbook\Interfaces\LogbookMasterRepositoryInterface');
                return $logbook_masterrepo->findorNew($logbook_master);
            });
        }

        if (Request::is('*/logbook/asset_logbook/*')) {
            Route::bind('asset_logbook', function ($asset_logbook) {
                $asset_logbookrepo = $this->app->make('Moblyze\Logbook\Interfaces\AssetLogbookRepositoryInterface');
                return $asset_logbookrepo->findorNew($asset_logbook);
            });
        }

        if (Request::is('*/logbook/safety_briefing/*')) {
            Route::bind('safety_briefing', function ($safety_briefing) {
                $safety_briefingrepo = $this->app->make('Moblyze\Logbook\Interfaces\SafetyBriefingRepositoryInterface');
                return $safety_briefingrepo->findorNew($safety_briefing);
            });
        }

        if (Request::is('*/logbook/vessel_logbook/*')) {
            Route::bind('vessel_logbook', function ($vessel_logbook) {
                $vessel_logbookrepo = $this->app->make('Moblyze\Logbook\Interfaces\VesselLogbookRepositoryInterface');
                return $vessel_logbookrepo->findorNew($vessel_logbook);
            });
        }

        if (Request::is('*/logbook/vessel_running_sheet/*')) {
            Route::bind('vessel_running_sheet', function ($vessel_running_sheet) {
                $vessel_running_sheetrepo = $this->app->make('Moblyze\Logbook\Interfaces\VesselRunningSheetRepositoryInterface');
                return $vessel_running_sheetrepo->findorNew($vessel_running_sheet);
            });
        }

        if (Request::is('*/logbook/iame_detail/*')) {
            Route::bind('iame_detail', function ($iame_detail) {
                $iame_detailrepo = $this->app->make('Moblyze\Logbook\Interfaces\IameDetailRepositoryInterface');
                return $iame_detailrepo->findorNew($iame_detail);
            });
        }

        if (Request::is('*/logbook/emergency_drill/*')) {
            Route::bind('emergency_drill', function ($emergency_drill) {
                $emergency_drillrepo = $this->app->make('Moblyze\Logbook\Interfaces\EmergencyDrillRepositoryInterface');
                return $emergency_drillrepo->findorNew($emergency_drill);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
